## Plan Update

### Question

This is the question we're working on answering:

{question}

### Completed Hypothesis

We have just completed work on the following hypothesis:

{current_hypothesis}

### Revise Plan

In completing our work, we may have learned something new. If so, consider modifying our plan to adjust accordingly e.g., if:

- We learned that a certain approach is not feasible, we may want to remove related work from our plan.
- We learned that a certain approach is feasible, we may want to add related work to our plan and remove any work that is no longer needed.
- New facts have come to light as a result of our work, we may want to update our plan accordingly.

#### Facts

Consider the following fact sheet when updating the plan:

{fact_sheet}

#### Team Composition

Consider the following team composition when updating the plan (do not involve any other outside people since we cannot contact anyone else):

{team_description}

#### Previous Plan

Here is the old plan:

{plan}
